package Math::SimpleHisto::XS::CLI;
use 5.008001;
use strict;
use warnings;

our $VERSION = '1.03';

use Math::SimpleHisto::XS;

# This is a dummy module for the indexer!

1;
__END__

=head1 NAME

Math::SimpleHisto::XS::CLI - Dummy module for the CLI tools

=head1 SYNOPSIS

  See the 'histify' and 'drawasciihist' CLI tools!

=head1 DESCRIPTION

This is a dummy module that simply serves as a way to make the
L<Math::SimpleHisto::XS>-related CLI tools installable separately
from the main module.

=head1 AUTHOR

Steffen Mueller, E<lt>smueller@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 by Steffen Mueller

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.1 or,
at your option, any later version of Perl 5 you may have available.

=cut
